@@ -1,11 +1,11 @@
-/* Copyright 2007 Free Software Foundation
+/* Copyright 2007, 2009 Free Software Foundation
  *
  * Copying and distribution of this file, with or without modification,
  * are permitted in any medium without royalty provided the copyright
  * notice and this notice are preserved.
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
@@ -22,7 +22,6 @@
  */
 
 #define MAX_BUF 1024
-#define SA struct sockaddr
 #define MSG "GET / HTTP/1.0\r\n\r\n"
 
 extern int tcp_connect (void);
